@@ -3,8 +3,8 @@ from .graphql_query_util import graphql_query
 from .json_util import load_json
 from .path_util import replace_sys_path, get_path_by_relative
 from .yaml_util import load_yaml
-# from .time_util import *
+from .time_util import *
 from .object import Object
 from .arg_util import Arg, Args
 
-__version__ = "1.1.2"
+__version__ = "1.2.0"
